==> seedsui-react-5.6.38.tgz: package/lib/TreePicker/Menu/Tree/index.js <==
var _excluded = ["itemRender", "keyword", "value", "list", "onChange", "onExpand", "onCollapse"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// require PrototypeArray.js
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import List from "./List"; // 树菜单选择

var Tree = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var itemRender = _ref.itemRender,
      keyword = _ref.keyword,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? [] : _ref$value,
      _ref$list = _ref.list,
      list = _ref$list === void 0 ? [] : _ref$list,
      onChange = _ref.onChange,
      onExpand = _ref.onExpand,
      onCollapse = _ref.onCollapse,
      props = _objectWithoutProperties(_ref, _excluded);

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });
  return /*#__PURE__*/React.createElement("ul", _extends({
    ref: rootRef
  }, props, {
    className: "treepicker-menu".concat(props.className ? ' ' + props.className : '')
  }), /*#__PURE__*/React.createElement(List, {
    rootRef: rootRef,
    itemRender: itemRender,
    keyword: keyword,
    value: value,
    list: list,
    onExpand: onExpand,
    onCollapse: onCollapse,
    onChange: onChange
  }));
});
export default Tree;

==> seedsui-react-5.6.54.tgz: package/lib/TreePicker/Menu/Tree/index.js <==
var _excluded = ["itemRender", "keyword", "value", "list", "onChange", "onExpand", "onCollapse"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

// require PrototypeArray.js
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import List from "./List"; // 树菜单选择

var Tree = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var itemRender = _ref.itemRender,
      keyword = _ref.keyword,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? [] : _ref$value,
      _ref$list = _ref.list,
      list = _ref$list === void 0 ? [] : _ref$list,
      onChange = _ref.onChange,
      onExpand = _ref.onExpand,
      onCollapse = _ref.onCollapse,
      props = _objectWithoutProperties(_ref, _excluded);

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      rootDOM: rootRef.current,
      getRootDOM: function getRootDOM() {
        return rootRef.current;
      }
    };
  });
  return /*#__PURE__*/React.createElement("ul", _extends({}, props, {
    className: "treepicker-menu".concat(props.className ? ' ' + props.className : ''),
    ref: rootRef
  }), /*#__PURE__*/React.createElement(List, {
    rootRef: rootRef,
    itemRender: itemRender,
    keyword: keyword,
    value: value,
    list: list,
    onExpand: onExpand,
    onCollapse: onCollapse,
    onChange: onChange
  }));
});
export default Tree;
